==> material-ui-redux-navigation-1.0.4.tgz: package/src/navigation/containers/NavigationContainer.js <==
import React from 'react';
import { connect } from 'react-redux';
import { getIsDrawerOpen, getCurrentPage, toggleDrawer, changePageName } from '../redux-integrated';

import muToolbar from '../presentation/muToolbar';
import muDrawer from '../presentation/muDrawer';
import SnackbarContainer from './SnackbarContainer';
import Paper from 'material-ui/Paper';

import Home from 'material-ui/svg-icons/action/home';
import Schedule from 'material-ui/svg-icons/action/schedule';
import AddBox from 'material-ui/svg-icons/content/add-box';

var Navigation = React.createClass({
  contextTypes: {
    router: React.PropTypes.object.isRequired
  },
  propTypes: {
    drawerOpen: React.PropTypes.bool.isRequired,
    pageTitle: React.PropTypes.string.isRequired,
    onToggleDrawer: React.PropTypes.func.isRequired,
    onTransition: React.PropTypes.func.isRequired,
    onLogout: React.PropTypes.func.isRequired,
    user: React.PropTypes.object.isRequired,
    children: React.PropTypes.element.isRequired
  },
  getInitialState: function() {
    return {
      user: {
        firstName: "Unknown",
        lastName: "User",
      },
      popoverOpen: false,
      anchorEl: null
    };
  },
  componentDidMount: function() {

  },
  handleTouchTapPopover: function(event) {
    // This prevents ghost click.
    event.preventDefault();
    this.setState({
      popoverOpen: true,
      anchorEl: event.currentTarget,
    });
  },
  handleClosePopover: function() {
    this.setState({
      popoverOpen: false,
    });
  },
  render: function() {
    // the left padding size is dependent on the drawer being opened or closed
    var leftPadding = this.props.drawerOpen && window.innerWidth >= 1440 ? '256px':'57px';
    document.title = this.props.pageTitle;
    return (
      <div>
        <muToolbar
          onLogout={this.props.onLogout}
          onToggleDrawer={this.props.onToggleDrawer}
          user={this.props.user}
          popoverOpen={this.state.popoverOpen}
          anchorEl={this.state.anchorEl}
          onTouchTapPopover={this.handleTouchTapPopover}
          onClosePopover={this.handleClosePopover}/>
        <muDrawer
          isOpen={this.props.drawerOpen}
          navTransitions={navTransitions}
          onTransition={this.props.onTransition}/>
        <Paper zDepth={0} style={{paddingLeft:leftPadding,paddingTop:'56px'}}>
          {this.props.children}
        </Paper>
        <SnackbarContainer />
      </div>
    );
  }
});

function mapStateToProps(state,ownProps){
  return {
    drawerOpen: getIsDrawerOpen(state),
    pageTitle: getCurrentPage(state),
    user: ownProps.user,
    navTransitions: ownProps.navTransitions,
    versionNumber: ownProps.versionNumber,

  };
}
function mapDispatchToProps(dispatch,ownProps){
  return {
    onToggleDrawer: () => {
      dispatch(toggleDrawer());
    },
    onTransition: (name) => {
      changePageName(dispatch,name);
    },
    onLogout: () => {
      ownProps.onLogout();
    }
  };
}
export default connect(mapStateToProps,mapDispatchToProps)(Navigation);

==> material-ui-redux-navigation-1.0.13.tgz: package/src/navigation/containers/NavigationContainer.js <==
import React from 'react';
import { connect } from 'react-redux';
import { getIsDrawerOpen, getCurrentPage, toggleDrawer, changePageName } from '../redux-integrated';

import MuToolbar from '../presentation/MuToolbar';
import MuDrawer from '../presentation/MuDrawer';
import Paper from 'material-ui/Paper';

import Home from 'material-ui/svg-icons/action/home';
import Schedule from 'material-ui/svg-icons/action/schedule';
import AddBox from 'material-ui/svg-icons/content/add-box';

var Navigation = React.createClass({
  contextTypes: {
    router: React.PropTypes.object.isRequired
  },
  propTypes: {
    drawerOpen: React.PropTypes.bool.isRequired,
    pageTitle: React.PropTypes.string.isRequired,
    onToggleDrawer: React.PropTypes.func.isRequired,
    onTransition: React.PropTypes.func.isRequired,
    onLogout: React.PropTypes.func.isRequired,
    user: React.PropTypes.object.isRequired,
    children: React.PropTypes.element.isRequired
  },
  getInitialState: function() {
    return {
      user: {
        firstName: "Unknown",
        lastName: "User",
      },
      popoverOpen: false,
      anchorEl: null
    };
  },
  componentDidMount: function() {

  },
  handleTouchTapPopover: function(event) {
    // This prevents ghost click.
    event.preventDefault();
    this.setState({
      popoverOpen: true,
      anchorEl: event.currentTarget,
    });
  },
  handleClosePopover: function() {
    this.setState({
      popoverOpen: false,
    });
  },
  render: function() {
    // the left padding size is dependent on the drawer being opened or closed
    var leftPadding = this.props.drawerOpen && window.innerWidth >= 1440 ? '256px':'57px';
    document.title = this.props.pageTitle;
    return (
      <div>
        <MuToolbar
          onLogout={this.props.onLogout}
          onToggleDrawer={this.props.onToggleDrawer}
          user={this.props.user}
          popoverOpen={this.state.popoverOpen}
          anchorEl={this.state.anchorEl}
          onTouchTapPopover={this.handleTouchTapPopover}
          onClosePopover={this.handleClosePopover}/>
        <MuDrawer
          isOpen={this.props.drawerOpen}
          navTransitions={this.props.navTransitions ? this.props.navTransitions : false}
          onTransition={this.props.onTransition}/>
        <Paper zDepth={0} style={{paddingLeft:leftPadding,paddingTop:'56px'}}>
          {this.props.children}
        </Paper>
      </div>
    );
  }
});

function mapStateToProps(state,ownProps){
  return {
    drawerOpen: getIsDrawerOpen(state),
    pageTitle: getCurrentPage(state),
    user: ownProps.user,
    navTransitions: ownProps.navTransitions,
    versionNumber: ownProps.versionNumber,

  };
}
function mapDispatchToProps(dispatch,ownProps){
  return {
    onToggleDrawer: () => dispatch(toggleDrawer()),
    onTransition: (name) => changePageName(dispatch,name),
    onLogout: () => ownProps.onLogout()
  };
}
export default connect(mapStateToProps,mapDispatchToProps)(Navigation);
